@@ -25,38 +25,34 @@ class BatchDeleteCdnDomainConfigRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cdn', '2018-05-10', 'BatchDeleteCdnDomainConfig')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_FunctionNames(self):
+	def get_FunctionNames(self): # String
 		return self.get_query_params().get('FunctionNames')
 
-	def set_FunctionNames(self,FunctionNames):
-		self.add_query_param('FunctionNames',FunctionNames)
-
-	def get_DomainNames(self):
+	def set_FunctionNames(self, FunctionNames):  # String
+		self.add_query_param('FunctionNames', FunctionNames)
+	def get_DomainNames(self): # String
 		return self.get_query_params().get('DomainNames')
 
-	def set_DomainNames(self,DomainNames):
-		self.add_query_param('DomainNames',DomainNames)
-
-	def get_OwnerAccount(self):
+	def set_DomainNames(self, DomainNames):  # String
+		self.add_query_param('DomainNames', DomainNames)
+	def get_OwnerAccount(self): # String
 		return self.get_query_params().get('OwnerAccount')
 
-	def set_OwnerAccount(self,OwnerAccount):
-		self.add_query_param('OwnerAccount',OwnerAccount)
-
-	def get_OwnerId(self):
+	def set_OwnerAccount(self, OwnerAccount):  # String
+		self.add_query_param('OwnerAccount', OwnerAccount)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_SecurityToken(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_SecurityToken(self): # String
 		return self.get_query_params().get('SecurityToken')
 
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
\ No newline at end of file
+	def set_SecurityToken(self, SecurityToken):  # String
+		self.add_query_param('SecurityToken', SecurityToken)
