@@ -25,44 +25,39 @@ class BatchUpdateCdnDomainRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cdn', '2018-05-10', 'BatchUpdateCdnDomain')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Sources(self):
+	def get_Sources(self): # String
 		return self.get_query_params().get('Sources')
 
-	def set_Sources(self,Sources):
-		self.add_query_param('Sources',Sources)
-
-	def get_ResourceGroupId(self):
+	def set_Sources(self, Sources):  # String
+		self.add_query_param('Sources', Sources)
+	def get_ResourceGroupId(self): # String
 		return self.get_query_params().get('ResourceGroupId')
 
-	def set_ResourceGroupId(self,ResourceGroupId):
-		self.add_query_param('ResourceGroupId',ResourceGroupId)
-
-	def get_SecurityToken(self):
+	def set_ResourceGroupId(self, ResourceGroupId):  # String
+		self.add_query_param('ResourceGroupId', ResourceGroupId)
+	def get_SecurityToken(self): # String
 		return self.get_query_params().get('SecurityToken')
 
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
-	def get_TopLevelDomain(self):
+	def set_SecurityToken(self, SecurityToken):  # String
+		self.add_query_param('SecurityToken', SecurityToken)
+	def get_TopLevelDomain(self): # String
 		return self.get_query_params().get('TopLevelDomain')
 
-	def set_TopLevelDomain(self,TopLevelDomain):
-		self.add_query_param('TopLevelDomain',TopLevelDomain)
-
-	def get_DomainName(self):
+	def set_TopLevelDomain(self, TopLevelDomain):  # String
+		self.add_query_param('TopLevelDomain', TopLevelDomain)
+	def get_DomainName(self): # String
 		return self.get_query_params().get('DomainName')
 
-	def set_DomainName(self,DomainName):
-		self.add_query_param('DomainName',DomainName)
-
-	def get_OwnerId(self):
+	def set_DomainName(self, DomainName):  # String
+		self.add_query_param('DomainName', DomainName)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
\ No newline at end of file
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
