@@ -36,8 +36,3 @@ class DescribeCertificateInfoByIDRequest(RpcRequest):
 
 	def set_CertId(self, CertId):  # String
 		self.add_query_param('CertId', CertId)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
