@@ -31,6 +31,21 @@ class DescribeDomainCcActivityLogRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
+	def get_DomainName(self): # String
+		return self.get_query_params().get('DomainName')
+
+	def set_DomainName(self, DomainName):  # String
+		self.add_query_param('DomainName', DomainName)
+	def get_PageSize(self): # Long
+		return self.get_query_params().get('PageSize')
+
+	def set_PageSize(self, PageSize):  # Long
+		self.add_query_param('PageSize', PageSize)
+	def get_EndTime(self): # String
+		return self.get_query_params().get('EndTime')
+
+	def set_EndTime(self, EndTime):  # String
+		self.add_query_param('EndTime', EndTime)
 	def get_RuleName(self): # String
 		return self.get_query_params().get('RuleName')
 
@@ -46,33 +61,13 @@ class DescribeDomainCcActivityLogRequest(RpcRequest):
 
 	def set_TriggerObject(self, TriggerObject):  # String
 		self.add_query_param('TriggerObject', TriggerObject)
-	def get_PageNumber(self): # Long
-		return self.get_query_params().get('PageNumber')
-
-	def set_PageNumber(self, PageNumber):  # Long
-		self.add_query_param('PageNumber', PageNumber)
-	def get_PageSize(self): # Long
-		return self.get_query_params().get('PageSize')
-
-	def set_PageSize(self, PageSize):  # Long
-		self.add_query_param('PageSize', PageSize)
 	def get_Value(self): # String
 		return self.get_query_params().get('Value')
 
 	def set_Value(self, Value):  # String
 		self.add_query_param('Value', Value)
-	def get_DomainName(self): # String
-		return self.get_query_params().get('DomainName')
+	def get_PageNumber(self): # Long
+		return self.get_query_params().get('PageNumber')
 
-	def set_DomainName(self, DomainName):  # String
-		self.add_query_param('DomainName', DomainName)
-	def get_EndTime(self): # String
-		return self.get_query_params().get('EndTime')
-
-	def set_EndTime(self, EndTime):  # String
-		self.add_query_param('EndTime', EndTime)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
+	def set_PageNumber(self, PageNumber):  # Long
+		self.add_query_param('PageNumber', PageNumber)
