@@ -31,11 +31,6 @@ class DescribeDomainSrcTopUrlVisitRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_StartTime(self): # String
-		return self.get_query_params().get('StartTime')
-
-	def set_StartTime(self, StartTime):  # String
-		self.add_query_param('StartTime', StartTime)
 	def get_DomainName(self): # String
 		return self.get_query_params().get('DomainName')
 
@@ -46,13 +41,13 @@ class DescribeDomainSrcTopUrlVisitRequest(RpcRequest):
 
 	def set_EndTime(self, EndTime):  # String
 		self.add_query_param('EndTime', EndTime)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
 	def get_SortBy(self): # String
 		return self.get_query_params().get('SortBy')
 
 	def set_SortBy(self, SortBy):  # String
 		self.add_query_param('SortBy', SortBy)
+	def get_StartTime(self): # String
+		return self.get_query_params().get('StartTime')
+
+	def set_StartTime(self, StartTime):  # String
+		self.add_query_param('StartTime', StartTime)
