@@ -36,8 +36,3 @@ class DescribeFCTriggerRequest(RpcRequest):
 
 	def set_TriggerARN(self, TriggerARN):  # String
 		self.add_query_param('TriggerARN', TriggerARN)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
