@@ -31,18 +31,13 @@ class DescribeUserUsageDataExportTaskRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_PageNumber(self): # String
-		return self.get_query_params().get('PageNumber')
-
-	def set_PageNumber(self, PageNumber):  # String
-		self.add_query_param('PageNumber', PageNumber)
 	def get_PageSize(self): # String
 		return self.get_query_params().get('PageSize')
 
 	def set_PageSize(self, PageSize):  # String
 		self.add_query_param('PageSize', PageSize)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
+	def get_PageNumber(self): # String
+		return self.get_query_params().get('PageNumber')
 
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
+	def set_PageNumber(self, PageNumber):  # String
+		self.add_query_param('PageNumber', PageNumber)
