@@ -36,11 +36,6 @@ class ListRealtimeLogDeliveryDomainsRequest(RpcRequest):
 
 	def set_Project(self, Project):  # String
 		self.add_query_param('Project', Project)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
 	def get_Region(self): # String
 		return self.get_query_params().get('Region')
 
