@@ -31,21 +31,16 @@ class ModifyRealtimeLogDeliveryRequest(RpcRequest):
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def get_Project(self): # String
-		return self.get_query_params().get('Project')
-
-	def set_Project(self, Project):  # String
-		self.add_query_param('Project', Project)
-	def get_OwnerId(self): # Long
-		return self.get_query_params().get('OwnerId')
-
-	def set_OwnerId(self, OwnerId):  # Long
-		self.add_query_param('OwnerId', OwnerId)
 	def get_Domain(self): # String
 		return self.get_query_params().get('Domain')
 
 	def set_Domain(self, Domain):  # String
 		self.add_query_param('Domain', Domain)
+	def get_Project(self): # String
+		return self.get_query_params().get('Project')
+
+	def set_Project(self, Project):  # String
+		self.add_query_param('Project', Project)
 	def get_Region(self): # String
 		return self.get_query_params().get('Region')
 
