@@ -25,32 +25,29 @@ class RefreshObjectCachesRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cdn', '2018-05-10', 'RefreshObjectCaches')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ObjectPath(self):
+	def get_ObjectPath(self): # String
 		return self.get_query_params().get('ObjectPath')
 
-	def set_ObjectPath(self,ObjectPath):
-		self.add_query_param('ObjectPath',ObjectPath)
-
-	def get_SecurityToken(self):
+	def set_ObjectPath(self, ObjectPath):  # String
+		self.add_query_param('ObjectPath', ObjectPath)
+	def get_SecurityToken(self): # String
 		return self.get_query_params().get('SecurityToken')
 
-	def set_SecurityToken(self,SecurityToken):
-		self.add_query_param('SecurityToken',SecurityToken)
-
-	def get_ObjectType(self):
+	def set_SecurityToken(self, SecurityToken):  # String
+		self.add_query_param('SecurityToken', SecurityToken)
+	def get_ObjectType(self): # String
 		return self.get_query_params().get('ObjectType')
 
-	def set_ObjectType(self,ObjectType):
-		self.add_query_param('ObjectType',ObjectType)
-
-	def get_OwnerId(self):
+	def set_ObjectType(self, ObjectType):  # String
+		self.add_query_param('ObjectType', ObjectType)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
\ No newline at end of file
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
